==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Circle/Circle3T/ts/Circle3T_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Circle2TR</name>
    <message>
        <source>Radius:</source>
        <translation type="obsolete">Raio:</translation>
    </message>
</context>
<context>
    <name>Circle3T</name>
    <message>
        <location filename="../Circle3T.js" line="+84"/>
        <source>First line, arc or circle</source>
        <translation>Primeira linha, arco, circulo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Second line, arc or circle</source>
        <translation>Segunda linha, arco, circulo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Third line, arc or circle</source>
        <translation>Terceiro linha, arco, circulo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Escolher solução</translation>
    </message>
    <message>
        <location line="+112"/>
        <location line="+59"/>
        <source>No solution</source>
        <translation>Nenhuma solução</translation>
    </message>
    <message>
        <location filename="../Circle3TInit.js" line="+2"/>
        <source>3 T&amp;angents</source>
        <translation>3 t&amp;angentes</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to three entities</source>
        <translation>Desenhe um círculo tangente a três entidades</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Circle/Circle3T/ts/Circle3T_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Circle2TR</name>
    <message>
        <source>Radius:</source>
        <translation type="obsolete">Raio:</translation>
    </message>
</context>
<context>
    <name>Circle3T</name>
    <message>
        <location filename="../Circle3T.js" line="+84"/>
        <source>First line, arc or circle</source>
        <translation>Primeira linha, arco ou círculo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Second line, arc or circle</source>
        <translation>Segunda linha, arco ou círculo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Third line, arc or circle</source>
        <translation>Terceira linha, arco ou círculo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Escolha uma solução</translation>
    </message>
    <message>
        <location line="+112"/>
        <location line="+60"/>
        <source>No solution</source>
        <translation>Nenhuma solução</translation>
    </message>
    <message>
        <location filename="../Circle3TInit.js" line="+2"/>
        <source>3 T&amp;angents</source>
        <translation>3 T&amp;angentes</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to three entities</source>
        <translation>Desenhe um círculo tangente a três entidades</translation>
    </message>
</context>
</TS>
